# JavaScript

The Launchable CLI includes built-in integrations for test runners and build tools that are popular in the JavaScript ecosystem:

* [Cypress](../integrations/cypress.md)
* [Jest](../integrations/jest.md)

See each integration's page for instructions to add Launchable to your CI pipeline.

